==> ng-zorro-antd-0.5.0-rc.4.tgz: package/src/showcase/nz-intro-index/README.md <==
NG-ZORRO [![GitHub stars](https://img.shields.io/github/stars/NG-ZORRO/ng-zorro-antd.svg?style=social&label=Star)](https://github.com/NG-ZORRO/ng-zorro-antd)
===
这里是 Ant Design 的 Angular`^4.0.0` 实现，开发和服务于企业级后台产品。

<div class="pic-plus">
  <img width="150" src="./assets/img/antd.svg">
  <span>+</span>
  <img width="180" src="./assets/img/angular.svg">
</div>


> 如果你刚开始学习前端或者Angular，将组件作为第一步可能并不是一个好主意，推荐先学习 <a href="http://www.angular.cn" target="_blank"> Angular </a> 和 <a href="https://www.typescriptlang.org/" target="_blank"> TypeScript</a>。

## 特性
- 提炼自企业级中后台产品的交互语言和视觉风格，定期与 Ant Design React 版本保持更新一致。
- 开箱即用的高质量 Angular 组件。
- 使用 TypeScript 构建，提供完整的类型定义文件。

## 版本

- [![npm package](https://img.shields.io/npm/v/ng-zorro-antd.svg)](https://www.npmjs.org/package/ng-zorro-antd)

## 支持环境

* 现代浏览器和 IE9 以上（需要 [polyfills](https://angular.cn/guide/browser-support)）。

## 兼容版本

* 当前支持 Angular`^4.0.0` 版本


## 安装

**我们推荐使用 npm 方式进行开发**，不仅可在开发环境轻松调试，也可放心地在生产环境打包部署使用，享受整个生态圈和工具链带来的诸多好处。

```bash
$ npm install ng-zorro-antd --save
```

如果你的网络环境不佳，推荐使用 [cnpm](https://github.com/cnpm/cnpm)。

## 标准开发

实际项目开发中，你会需要对 TypeScript 代码的构建、调试、代理、打包部署等一系列工程化的需求。
我们推荐官方的 `@angular/cli` 工具链辅助进行开发

如果你想了解更多CLI工具链的功能和命令，建议访问 [Angular CLI](https://github.com/angular/angular-cli) 了解更多


## 链接

- [首页](http://ng.ant.design)
- [Angular官方文档](https://angular.cn/)
- [开发脚手架](https://cli.angular.io/)
- [TypeScript](https://www.typescriptlang.org/)
- [RxJS 5](https://github.com/ReactiveX/rxjs)


## 如何贡献

如果你希望参与贡献，欢迎 [Pull Request](https://github.com/NG-ZORRO/ng-zorro-antd/pulls)，或给我们 [报告 Bug](https://github.com/NG-ZORRO/ng-zorro-antd/issues)。

> 强烈推荐阅读 [《提问的智慧》](https://github.com/ryanhanwu/How-To-Ask-Questions-The-Smart-Way)、[《如何向开源社区提问题》](https://github.com/seajs/seajs/issues/545) 和 [《如何有效地报告 Bug》](http://www.chiark.greenend.org.uk/%7Esgtatham/bugs-cn.html)、[《如何向开源项目提交无法解答的问题》](https://zhuanlan.zhihu.com/p/25795393)，更好的问题更容易获得帮助。

## 关于NG-ZORRO

​众所周知，Ant Design作为一门设计语言面世，经历过多年的迭代和积累，它对UI的设计思想已经成为一套事实标准，受到众多前端开发者及企业的追捧和喜爱，也是React开发者手中的神兵利器。希望NG-ZORRO能够让Angular开发者也享受到Ant Design的优秀设计。

作为Ant Design的Angular实现，NG-ZORRO不仅继承了Ant Design的独到思想和极致体验，同时也结合了Angular框架的优点和特性。目前第一版发布将支持Angular 4.0.0及以上版本，组件的数量现已覆盖Ant Design React版本的80%以上，组件的风格已与Ant Design最新版本保持同步，组件的接口也尽量保持了与Ant Design的React版本一致（由于Angular的某些特性区别，某些组件的使用方式可能有所改变）。

NG-ZORRO 致力于提供给 Angular 开发者愉悦的开发体验。

## 关于开发者

NG-ZORRO由阿里计算平台事业部、阿里云等不同部门的一些小伙伴在原业务组件的基础上共同构建而成，在这个过程中得到了蚂蚁金服Ant Design团队的很多帮助。在最后开源的准备中也得到了很多社区小伙伴的支持和PR，在这里感谢大家。

欢迎各位社区开发者加入我们，共同开发和维护NG-ZORRO，期待您的帮助。

## THANK YOU

VTHINKXIE, Wilson Zeng, chensimeng, zjgzx1988, SunMing, fbchen, Trotyl Yu, 雪狼, afc163, xufei, lightningtgc

==> ng-zorro-antd-0.6.0-rc.1.tgz: package/src/showcase/nz-intro-index/README.md <==
NG-ZORRO [![GitHub stars](https://img.shields.io/github/stars/NG-ZORRO/ng-zorro-antd.svg?style=social&label=Star)](https://github.com/NG-ZORRO/ng-zorro-antd)
===
这里是 Ant Design 的 Angular`^4.4.4` 实现，开发和服务于企业级后台产品。

<div class="pic-plus">
  <img width="150" src="./assets/img/antd.svg">
  <span>+</span>
  <img width="180" src="./assets/img/angular.svg">
</div>


> 如果你刚开始学习前端或者Angular，将组件作为第一步可能并不是一个好主意，推荐先学习 <a href="http://www.angular.cn" target="_blank"> Angular </a> 和 <a href="https://www.typescriptlang.org/" target="_blank"> TypeScript</a>。

## 特性
- 提炼自企业级中后台产品的交互语言和视觉风格，定期与 Ant Design React 版本保持更新一致。
- 开箱即用的高质量 Angular 组件。
- 使用 TypeScript 构建，提供完整的类型定义文件。

## 版本

- [![npm package](https://img.shields.io/npm/v/ng-zorro-antd.svg)](https://www.npmjs.org/package/ng-zorro-antd)

## 支持环境

* 现代浏览器和 IE9 以上（需要 [polyfills](https://angular.cn/guide/browser-support)）。

## 兼容版本

* 当前支持 Angular`^4.4.4` 版本（`4.4.4`以下推荐使用`ng-zorro-antd`的`0.5.x`版本）


## 安装

**我们推荐使用 npm 方式进行开发**，不仅可在开发环境轻松调试，也可放心地在生产环境打包部署使用，享受整个生态圈和工具链带来的诸多好处。

```bash
$ npm install ng-zorro-antd --save
```

如果你的网络环境不佳，推荐使用 [cnpm](https://github.com/cnpm/cnpm)。

## 标准开发

实际项目开发中，你会需要对 TypeScript 代码的构建、调试、代理、打包部署等一系列工程化的需求。
我们推荐官方的 `@angular/cli` 工具链辅助进行开发

如果你想了解更多CLI工具链的功能和命令，建议访问 [Angular CLI](https://github.com/angular/angular-cli) 了解更多


## 历史版本入口

- [0.5.x](http://ng.ant.design/version/0.5.x)


## 链接

- [首页](http://ng.ant.design)
- [Angular官方文档](https://angular.cn/)
- [开发脚手架](https://cli.angular.io/)
- [TypeScript](https://www.typescriptlang.org/)
- [RxJS 5](https://github.com/ReactiveX/rxjs)


## 如何贡献

如果你希望参与贡献，欢迎 [Pull Request](https://github.com/NG-ZORRO/ng-zorro-antd/pulls)，或给我们 [报告 Bug](https://github.com/NG-ZORRO/ng-zorro-antd/issues)。

> 强烈推荐阅读 [《提问的智慧》](https://github.com/ryanhanwu/How-To-Ask-Questions-The-Smart-Way)、[《如何向开源社区提问题》](https://github.com/seajs/seajs/issues/545) 和 [《如何有效地报告 Bug》](http://www.chiark.greenend.org.uk/%7Esgtatham/bugs-cn.html)、[《如何向开源项目提交无法解答的问题》](https://zhuanlan.zhihu.com/p/25795393)，更好的问题更容易获得帮助。

## 关于NG-ZORRO

​众所周知，Ant Design作为一门设计语言面世，经历过多年的迭代和积累，它对UI的设计思想已经成为一套事实标准，受到众多前端开发者及企业的追捧和喜爱，也是React开发者手中的神兵利器。希望NG-ZORRO能够让Angular开发者也享受到Ant Design的优秀设计。

作为Ant Design的Angular实现，NG-ZORRO不仅继承了Ant Design的独到思想和极致体验，同时也结合了Angular框架的优点和特性。目前第一版发布将支持Angular 4.0.0及以上版本，组件的数量现已覆盖Ant Design React版本的80%以上，组件的风格已与Ant Design最新版本保持同步，组件的接口也尽量保持了与Ant Design的React版本一致（由于Angular的某些特性区别，某些组件的使用方式可能有所改变）。

NG-ZORRO 致力于提供给 Angular 开发者愉悦的开发体验。

## 关于开发者

NG-ZORRO由阿里计算平台事业部、阿里云等不同部门的一些小伙伴在原业务组件的基础上共同构建而成，在这个过程中得到了蚂蚁金服Ant Design团队的很多帮助。在最后开源的准备中也得到了很多社区小伙伴的支持和PR，在这里感谢大家。

欢迎各位社区开发者加入我们，共同开发和维护NG-ZORRO，期待您的帮助。

## THANK YOU

VTHINKXIE, Wilson Zeng, chensimeng, zjgzx1988, SunMing, fbchen, Trotyl Yu, 雪狼, afc163, xufei, lightningtgc
